@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2006  Michel de Boer <michelboer@xs4all.nl>
+    Copyright (C) 2005-2007  Michel de Boer <michel@twinklephone.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,7 +21,9 @@
 
 #include <sys/time.h>
 #include "qlistview.h"
+#include "qpainter.h"
 #include "call_history.h"
+#include "user.h"
 
 // Columns of the history list view
 #define HISTCOL_TIMESTAMP 	0
@@ -33,10 +35,14 @@
 class HistoryListViewItem : public QListViewItem {
 private:
 	t_call_record	call_record;
+	time_t		last_viewed;
 	
 public:
-	HistoryListViewItem( QListView * parent, const t_call_record &cr, QString label2 = QString::null, QString label3 = QString::null, QString label4 = QString::null, QString label5 = QString::null, QString label6 = QString::null, QString label7 = QString::null, QString label8 = QString::null );
+	HistoryListViewItem( QListView * parent, const t_call_record &cr, t_user *user_config,
+			     time_t _last_viewed);
 	
+	void paintCell(QPainter *painter, const QColorGroup &cg, 
+				    int column, int width, int align);
 	int compare ( QListViewItem * i, int col, bool ascending ) const;
 	time_t get_time_start(void) const;
 	t_call_record get_call_record(void) const;
