@@ -7,7 +7,7 @@
 ** place of a destructor.
 *****************************************************************************/
 /*
-    Copyright (C) 2005-2006  Michel de Boer <michelboer@xs4all.nl>
+    Copyright (C) 2005-2007  Michel de Boer <michel@twinklephone.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -39,12 +39,6 @@ void RedirectForm::init()
 	address1ToolButton->setIconSet(i);
 	address2ToolButton->setIconSet(i);
 	address3ToolButton->setIconSet(i);
-	
-#ifndef HAVE_KDE
-	address1ToolButton->setEnabled(false);
-	address2ToolButton->setEnabled(false);
-	address3ToolButton->setEnabled(false);
-#endif
 }
 
 void RedirectForm::destroy()
