@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2006  Michel de Boer <michelboer@xs4all.nl>
+    Copyright (C) 2005-2007  Michel de Boer <michel@twinklephone.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,25 +19,13 @@
 #include "hdr_accept_encoding.h"
 #include "definitions.h"
 
-t_hdr_accept_encoding::t_hdr_accept_encoding() : t_header() {};
+t_hdr_accept_encoding::t_hdr_accept_encoding() : t_header("Accept-Encoding") {};
 
 void t_hdr_accept_encoding::add_coding(const t_coding &coding) {
 	populated = true;
 	coding_list.push_back(coding);
 }
 
-string t_hdr_accept_encoding::encode(void) const {
-	string s;
-
-	if (!populated) return s;
-
-	s += "Accept-Encoding: ";
-	s += encode_value();
-	s += CRLF;
-
-	return s;
-}
-
 string t_hdr_accept_encoding::encode_value(void) const {
 	string s;
 
@@ -46,18 +34,9 @@ string t_hdr_accept_encoding::encode_value(void) const {
 	for (list<t_coding>::const_iterator i = coding_list.begin();
 	     i != coding_list.end(); i++)
 	{
-		if (i != coding_list.begin()) s += ", ";
+		if (i != coding_list.begin()) s += ",";
 		s += i->encode();
 	}
 
 	return s;
 }
-
-string t_hdr_accept_encoding::encode_env(void) const {
-	string s;
-	
-	s = "SIP_ACCEPT_ENCODING=";
-	s += encode_value();
-	
-	return s;
-}
