@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2006  Michel de Boer <michelboer@xs4all.nl>
+    Copyright (C) 2005-2007  Michel de Boer <michel@twinklephone.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,30 +19,13 @@
 #include "hdr_allow_events.h"
 #include "parse_ctrl.h"
 
-t_hdr_allow_events::t_hdr_allow_events() : t_header() {}
+t_hdr_allow_events::t_hdr_allow_events() : t_header("Allow-Events", "u") {}
 
 void t_hdr_allow_events::add_event_type(const string &t) {
 	populated = true;
 	event_types.push_back(t);
 }
 
-string t_hdr_allow_events::encode(void) const {
-	string s;
-
-	if (!populated) return s;
-
-	if (t_parser::compact_headers) {
-		s = "u: ";
-	} else {
-		s = "Allow-Events: ";
-	}
-	
-	s += encode_value();
-	s += CRLF;
-	
-	return s;
-}
-
 string t_hdr_allow_events::encode_value(void) const {
 	string s;
 
@@ -51,18 +34,9 @@ string t_hdr_allow_events::encode_value(void) const {
 	for (list<string>::const_iterator i = event_types.begin();
 	     i != event_types.end(); i++)
 	{
-		if (i != event_types.begin()) s += ", ";
+		if (i != event_types.begin()) s += ",";
 		s += *i;
 	}
 
 	return s;
 }
-
-string t_hdr_allow_events::encode_env(void) const {
-	string s;
-	
-	s = "SIP_ALLOW_EVENTS=";
-	s += encode_value();
-	
-	return s;
-}
