@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2006  Michel de Boer <michelboer@xs4all.nl>
+    Copyright (C) 2005-2007  Michel de Boer <michel@twinklephone.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #include "definitions.h"
 #include "util.h"
 
-t_hdr_auth_info::t_hdr_auth_info() : t_header() {
+t_hdr_auth_info::t_hdr_auth_info() : t_header("Authentication-Info") {
 	nonce_count = 0;
 }
 
@@ -49,18 +49,6 @@ void t_hdr_auth_info::set_nonce_count(const unsigned long &nc) {
 	nonce_count = nc;
 }
 
-string t_hdr_auth_info::encode(void) const {
-	string s;
-
-	if (!populated) return s;
-
-	s += "Authenticate-Info: ";
-	s += encode_value();
-	s += CRLF;
-
-	return s;
-}
-
 string t_hdr_auth_info::encode_value(void) const {
 	string s;
 	bool add_comma = false;
@@ -109,12 +97,3 @@ string t_hdr_auth_info::encode_value(void) const {
 
 	return s;
 }
-
-string t_hdr_auth_info::encode_env(void) const {
-	string s;
-	
-	s = "SIP_AUTHENTICATE_INFO=";
-	s += encode_value();
-	
-	return s;
-}
