@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2006  Michel de Boer <michelboer@xs4all.nl>
+    Copyright (C) 2005-2007  Michel de Boer <michel@twinklephone.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,40 +20,14 @@
 #include "definitions.h"
 #include "parse_ctrl.h"
 
-t_hdr_call_id::t_hdr_call_id() : t_header() {};
+t_hdr_call_id::t_hdr_call_id() : t_header("Call-ID", "i") {};
 
-void t_hdr_call_id::set_call_id(string id) {
+void t_hdr_call_id::set_call_id(const string &id) {
 	populated = true;
 	call_id = id;
 }
 
-string t_hdr_call_id::encode(void) const {
-	string s;
-
-	if (!populated) return s;
-
-	if (t_parser::compact_headers) {
-		s = "i: ";
-	} else {
-		s = "Call-ID: ";
-	}
-
-	s += encode_value();
-	s += CRLF;
-
-	return s;
-}
-
 string t_hdr_call_id::encode_value(void) const {
 	if (!populated) return "";
 	return call_id;
 }
-
-string t_hdr_call_id::encode_env(void) const {
-	string s;
-	
-	s = "SIP_CALL_ID=";
-	s += encode_value();
-	
-	return s;
-}
