@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2006  Michel de Boer <michelboer@xs4all.nl>
+    Copyright (C) 2005-2007  Michel de Boer <michel@twinklephone.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -33,25 +33,13 @@ string t_info_param::encode(void) const {
 }
 
 
-t_hdr_call_info::t_hdr_call_info() : t_header() {};
+t_hdr_call_info::t_hdr_call_info() : t_header("Call-Info") {};
 
 void t_hdr_call_info::add_param(const t_info_param &p) {
 	populated = true;
 	info_param_list.push_back(p);
 }
 
-string t_hdr_call_info::encode(void) const {
-	string s;
-
-	if (!populated) return s;
-
-	s += "Call-Info: ";
-	s += encode_value();
-	s += CRLF;
-
-	return s;
-}
-
 string t_hdr_call_info::encode_value(void) const {
 	string s;
 
@@ -66,12 +54,3 @@ string t_hdr_call_info::encode_value(void) const {
 	
 	return s;
 }
-
-string t_hdr_call_info::encode_env(void) const {
-	string s;
-	
-	s = "SIP_CALL_INFO=";
-	s += encode_value();
-	
-	return s;
-}
