@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2006  Michel de Boer <michelboer@xs4all.nl>
+    Copyright (C) 2005-2007  Michel de Boer <michel@twinklephone.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,30 +20,13 @@
 #include "definitions.h"
 #include "parse_ctrl.h"
 
-t_hdr_content_encoding::t_hdr_content_encoding() : t_header() {};
+t_hdr_content_encoding::t_hdr_content_encoding() : t_header("Content-Encoding", "e") {};
 
 void t_hdr_content_encoding::add_coding(const t_coding &coding) {
 	populated = true;
 	coding_list.push_back(coding);
 }
 
-string t_hdr_content_encoding::encode(void) const {
-	string s;
-
-	if (!populated) return s;
-
-	if (t_parser::compact_headers) {
-		s = "e: ";
-	} else {
-		s = "Content-Encoding: ";
-	}
-
-	s += encode_value();
-	s += CRLF;
-
-	return s;
-}
-
 string t_hdr_content_encoding::encode_value(void) const {
 	string s;
 
@@ -58,12 +41,3 @@ string t_hdr_content_encoding::encode_value(void) const {
 
 	return s;
 }
-
-string t_hdr_content_encoding::encode_env(void) const {
-	string s;
-	
-	s = "SIP_CONTENT_ENCODING=";
-	s += encode_value();
-	
-	return s;
-}
