@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2006  Michel de Boer <michelboer@xs4all.nl>
+    Copyright (C) 2005-2007  Michel de Boer <michel@twinklephone.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #include "hdr_expires.h"
 #include "util.h"
 
-t_hdr_expires::t_hdr_expires() : t_header() {
+t_hdr_expires::t_hdr_expires() : t_header("Expires") {
 	time = 0;
 }
 
@@ -29,29 +29,8 @@ void t_hdr_expires::set_time(unsigned long t) {
 	time = t;
 }
 
-string t_hdr_expires::encode(void) const {
-	string s;
-
-	if (!populated) return s;
-
-	s = "Expires: ";
-	s += encode_value();
-	s += CRLF;
-	
-	return s;
-}
-
 string t_hdr_expires::encode_value(void) const {
 	if (!populated) return "";
 
 	return ulong2str(time);
 }
-
-string t_hdr_expires::encode_env(void) const {
-	string s;
-
-	s = "SIP_EXPIRES=";
-	s += encode_value();
-	
-	return s;
-}
