@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2006  Michel de Boer <michelboer@xs4all.nl>
+    Copyright (C) 2005-2007  Michel de Boer <michel@twinklephone.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,25 +19,13 @@
 #include "hdr_in_reply_to.h"
 #include "definitions.h"
 
-t_hdr_in_reply_to::t_hdr_in_reply_to() : t_header() {};
+t_hdr_in_reply_to::t_hdr_in_reply_to() : t_header("In-Reply-To") {};
 
 void t_hdr_in_reply_to::add_call_id(const string &id) {
 	populated = true;
 	call_ids.push_back(id);
 }
 
-string t_hdr_in_reply_to::encode(void) const {
-	string s;
-
-	if (!populated) return s;
-
-	s = "In-Reply-To: ";
-	s += encode_value();
-	s += CRLF;
-	
-	return s;
-}
-
 string t_hdr_in_reply_to::encode_value(void) const {
 	string s;
 
@@ -52,12 +40,3 @@ string t_hdr_in_reply_to::encode_value(void) const {
 
 	return s;
 }
-
-string t_hdr_in_reply_to::encode_env(void) const {
-	string s;
-	
-	s = "SIP_IN_REPLY_TO=";
-	s += encode_value();
-	
-	return s;
-}
