@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2006  Michel de Boer <michelboer@xs4all.nl>
+    Copyright (C) 2005-2007  Michel de Boer <michel@twinklephone.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,37 +19,15 @@
 #include "definitions.h"
 #include "hdr_mime_version.h"
 
-t_hdr_mime_version::t_hdr_mime_version() : t_header() {};
+t_hdr_mime_version::t_hdr_mime_version() : t_header("MIME-Version") {};
 
 void t_hdr_mime_version::set_version(const string &v) {
 	populated = true;
 	version = v;
 }
 
-string t_hdr_mime_version::encode(void) const {
-	string s;
-
-	if (!populated) return s;
-
-	s = "MIME-Version: ";
-	s += encode_value();
-	s += CRLF;
-	
-	return s;
-}
-
 string t_hdr_mime_version::encode_value(void) const {
 	if (!populated) return "";
 
 	return version;
 }
-
-string t_hdr_mime_version::encode_env(void) const {
-	string s;
-
-	s = "SIP_MIME_VERSION=";
-	s += encode_value();
-	
-	return s;
-}
-	
\ No newline at end of file
