@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2006  Michel de Boer <michelboer@xs4all.nl>
+    Copyright (C) 2005-2007  Michel de Boer <michel@twinklephone.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #include "hdr_rack.h"
 #include "util.h"
 
-t_hdr_rack::t_hdr_rack() : t_header() {
+t_hdr_rack::t_hdr_rack() : t_header("RAck") {
 	cseq_nr = 0;
 	resp_nr = 0;
 	method = INVITE;
@@ -50,18 +50,6 @@ void t_hdr_rack::set_method(const string &s) {
 	}
 }
 
-string t_hdr_rack::encode(void) const {
-	string s;
-
-	if (!populated) return s;
-
-	s = "RAck: ";
-	s += encode_value();
-	s += CRLF;
-	
-	return s;
-}
-
 string t_hdr_rack::encode_value(void) const {
 	string s;
 
@@ -74,12 +62,3 @@ string t_hdr_rack::encode_value(void) const {
 
 	return s;
 }
-
-string t_hdr_rack::encode_env(void) const {
-	string s;
-	
-	s = "SIP_RACK=";
-	s += encode_value();
-	
-	return s;
-}
