@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2006  Michel de Boer <michelboer@xs4all.nl>
+    Copyright (C) 2005-2007  Michel de Boer <michel@twinklephone.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,11 +31,10 @@ public:
 
 	t_hdr_require();
 	void add_feature(const string &f);
+	void add_features(const list<string> &l);
 	void del_feature(const string &f);
 	bool contains(const string &f) const;
-	string encode(void) const;
 	string encode_value(void) const;
-	string encode_env(void) const;
 	void unpopulate(void);
 };
 
