@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2006  Michel de Boer <michelboer@xs4all.nl>
+    Copyright (C) 2005-2007  Michel de Boer <michel@twinklephone.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #include "hdr_retry_after.h"
 #include "util.h"
 
-t_hdr_retry_after::t_hdr_retry_after() : t_header() {
+t_hdr_retry_after::t_hdr_retry_after() : t_header("Retry-After") {
 	time = 0;
 	duration = 0;
 }
@@ -45,18 +45,6 @@ void t_hdr_retry_after::add_param(const t_parameter &p) {
 	params.push_back(p);
 }
 
-string t_hdr_retry_after::encode(void) const {
-	string s;
-
-	if (!populated) return s;
-
-	s = "Retry-After: ";
-	s += encode_value();
-	s += CRLF;
-	
-	return s;
-}
-
 string t_hdr_retry_after::encode_value(void) const {
 	string s;
 
@@ -79,12 +67,3 @@ string t_hdr_retry_after::encode_value(void) const {
 
 	return s;
 }
-
-string t_hdr_retry_after::encode_env(void) const {
-	string s;
-	
-	s = "SIP_RETRY_AFTER=";
-	s += encode_value();
-	
-	return s;
-}
