@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2006  Michel de Boer <michelboer@xs4all.nl>
+    Copyright (C) 2005-2007  Michel de Boer <michel@twinklephone.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #include "hdr_rseq.h"
 #include "util.h"
 
-t_hdr_rseq::t_hdr_rseq() : t_header() {
+t_hdr_rseq::t_hdr_rseq() : t_header("RSeq") {
 	resp_nr = 0;
 }
 
@@ -29,32 +29,12 @@ void t_hdr_rseq::set_resp_nr(unsigned long l) {
 	resp_nr = l;
 }
 
-string t_hdr_rseq::encode(void) const {
-	string s;
-
-	if (!populated) return s;
-
-	s = "RSeq: ";
-	s += encode_value();
-	s += CRLF;
-	return s;
-}
-
 string t_hdr_rseq::encode_value(void) const {
 	if (!populated) return "";
 
 	return ulong2str(resp_nr);
 }
 
-string t_hdr_rseq::encode_env(void) const {
-	string s;
-	
-	s = "SIP_RSEQ=";
-	s += encode_value();
-	
-	return s;
-}
-
 bool t_hdr_rseq::operator==(const t_hdr_rseq &h) const {
 	return (resp_nr == h.resp_nr);
 }
