@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2006  Michel de Boer <michelboer@xs4all.nl>
+    Copyright (C) 2005-2007  Michel de Boer <michel@twinklephone.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,42 +20,15 @@
 #include "hdr_subject.h"
 #include "parse_ctrl.h"
 
-t_hdr_subject::t_hdr_subject() : t_header() {};
+t_hdr_subject::t_hdr_subject() : t_header("Subject", "s") {};
 
 void t_hdr_subject::set_subject(const string &s) {
 	populated = true;
 	subject = s;
 }
 
-string t_hdr_subject::encode(void) const {
-	string s;
-
-	if (!populated) return s;
-
-	if (t_parser::compact_headers) {
-		s = "s: ";
-	} else {
-		s = "Subject: ";
-	}
-
-	s += encode_value();
-	s += CRLF;
-	
-	return s;
-}
-
 string t_hdr_subject::encode_value(void) const {
 	if (!populated) return "";
 
 	return subject;
 }
-
-string t_hdr_subject::encode_env(void) const {
-	string s;
-
-	s = "SIP_SUBJECT=";
-	s += encode_value();
-	
-	return s;
-}
-	
\ No newline at end of file
