@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2006  Michel de Boer <michelboer@xs4all.nl>
+    Copyright (C) 2005-2007  Michel de Boer <michel@twinklephone.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #include "hdr_subscription_state.h"
 #include "util.h"
 
-t_hdr_subscription_state::t_hdr_subscription_state() : t_header() {
+t_hdr_subscription_state::t_hdr_subscription_state() : t_header("Subscription-State") {
 	expires = 0;
 	retry_after = 0;
 }
@@ -50,18 +50,6 @@ void t_hdr_subscription_state::add_extension(const t_parameter &p) {
 	extensions.push_back(p);
 }
 
-string t_hdr_subscription_state::encode(void) const {
-	string s;
-
-	if (!populated) return s;
-
-	s = "Subscription-State: ";
-	s += encode_value();
-	s += CRLF;
-	
-	return s;
-}
-
 string t_hdr_subscription_state::encode_value(void) const {
 	string s;
 
@@ -88,12 +76,3 @@ string t_hdr_subscription_state::encode_value(void) const {
 
 	return s;
 }
-
-string t_hdr_subscription_state::encode_env(void) const {
-	string s;
-	
-	s = "SIP_SUBSCRIPTION_STATE=";
-	s += encode_value();
-	
-	return s;
-}
