@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2006  Michel de Boer <michelboer@xs4all.nl>
+    Copyright (C) 2005-2007  Michel de Boer <michel@twinklephone.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #include "hdr_timestamp.h"
 #include "util.h"
 
-t_hdr_timestamp::t_hdr_timestamp() : t_header() {
+t_hdr_timestamp::t_hdr_timestamp() : t_header("Timestamp") {
 	timestamp = 0;
 	delay = 0;
 }
@@ -35,18 +35,6 @@ void t_hdr_timestamp::set_delay(float d) {
 	delay = d;
 }
 
-string t_hdr_timestamp::encode(void) const {
-	string s;
-
-	if (!populated) return s;
-
-	s = "Timestamp: ";
-	s += encode_value();
-	s += CRLF;
-	
-	return s;
-}
-
 string t_hdr_timestamp::encode_value(void) const {
 	string s;
 
@@ -58,12 +46,3 @@ string t_hdr_timestamp::encode_value(void) const {
 
 	return s;
 }
-
-string t_hdr_timestamp::encode_env(void) const {
-	string s;
-	
-	s = "SIP_TIMESTAMP=";
-	s += encode_value();
-	
-	return s;
-}
