@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2006  Michel de Boer <michelboer@xs4all.nl>
+    Copyright (C) 2005-2007  Michel de Boer <michel@twinklephone.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -63,10 +63,8 @@ public:
 	t_hdr_via();
 	void add_via(const t_via &v);
 	string encode(void) const;
-	string encode_list(void) const;
 	string encode_multi_header(void) const;
 	string encode_value(void) const;
-	string encode_env(void) const;
 
 	// Get the response destination
 	void get_response_dst(unsigned long &ipaddr, unsigned short &prt);
