@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2006  Michel de Boer <michelboer@xs4all.nl>
+    Copyright (C) 2005-2007  Michel de Boer <michel@twinklephone.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -66,25 +66,13 @@ string t_warning::encode(void) const {
 	return s;
 }
 
-t_hdr_warning::t_hdr_warning() : t_header() {}
+t_hdr_warning::t_hdr_warning() : t_header("Warning") {}
 
 void t_hdr_warning::add_warning(const t_warning &w) {
 	populated = true;
 	warnings.push_back(w);
 }
 
-string t_hdr_warning::encode(void) const {
-	string s;
-
-	if (!populated) return s;
-
-	s = "Warning: ";
-	s += encode_value();
-	s += CRLF;
-	
-	return s;
-}
-
 string t_hdr_warning::encode_value(void) const {
 	string s;
 
@@ -99,12 +87,3 @@ string t_hdr_warning::encode_value(void) const {
 
 	return s;
 }
-
-string t_hdr_warning::encode_env(void) const {
-	string s;
-
-	s = "SIP_WARNING=";
-	s += encode_value();
-	
-	return s;
-}
