@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2006  Michel de Boer <michelboer@xs4all.nl>
+    Copyright (C) 2005-2007  Michel de Boer <michel@twinklephone.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -273,11 +273,25 @@ bool t_request::is_valid(bool &fatal, string &reason) const {
 			reason = "Event header missing";
 			return false;
 		}
-
-		if (!hdr_subscription_state.is_populated()) {
-			reason = "Subscription-State header missing";
-			return false;
+		
+		// RFC 3265 7.2
+		// Subscription-State header is mandatory
+		// As an exception Twinkle allows an unsollicited NOTIFY for MWI
+		// without a Subscription-State header. Asterisk sends
+		// unsollicited NOTIFY requests.
+		if (!hdr_to.tag.empty() || 
+		    hdr_event.event_type != SIP_EVENT_MSG_SUMMARY)
+		{
+			if (!hdr_subscription_state.is_populated()) {
+				reason = "Subscription-State header missing";
+			 	return false;
+			 }
 		}
+
+		// The Subscription-State header is mandatory.
+		// However, Asterisk uses an expired draft for sending
+		// unsollicitied NOTIFY messages without a Subscription-State
+		// header. As Asterisk is popular, Twinkle allows this.
 		break;
 	case REFER:
 		// RFC 3515 2.4.1
@@ -287,6 +301,14 @@ bool t_request::is_valid(bool &fatal, string &reason) const {
 		}
 		break;
 	}
+	
+	if (hdr_replaces.is_populated()) {
+		// RFC 3891 3
+		if (method != INVITE) {
+			reason = "Replaces header not allowed";
+			return false;
+		}
+	}
 
 	return true;
 }
@@ -299,6 +321,17 @@ void t_request::calc_destinations(const t_user &user_profile) {
 		destinations = user_profile.get_registrar().get_h_ip_srv("udp");
 		return;
 	}
+	
+	// Bypass the proxy for an out-of-dialog SUBSCRIBE if provisioned.
+	if (method == SUBSCRIBE && hdr_to.tag.empty()) {
+		if (hdr_event.event_type == SIP_EVENT_MSG_SUMMARY) {
+			if (!user_profile.get_mwi_via_proxy()) {
+				// Take Request-URI
+				destinations = uri.get_h_ip_srv("udp");
+				return;
+			}
+		}
+	}
 
 	if (!user_profile.get_use_outbound_proxy() ||
 	    (hdr_to.tag != "" && !user_profile.get_all_requests_to_proxy())) {
