@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2006  Michel de Boer <michelboer@xs4all.nl>
+    Copyright (C) 2005-2007  Michel de Boer <michel@twinklephone.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #define _SUB_REFER_H
 
 #include "subscription.h"
+#include "dialog.h"
 
 // State of reference as seen by the referrer
 enum t_sub_refer_result {
@@ -41,6 +42,8 @@ private:
 
 	// Current substate of the notification
 	string			current_substate;
+	
+	t_dialog *get_dialog(void) const;
 
 public:
 	t_sub_refer(t_dialog *_dialog, t_subscription_role _role);
@@ -59,8 +62,6 @@ public:
 
 	bool timeout(t_subscribe_timer timer);
 
-	void refresh_subscribe(void);
-
 	t_sub_refer_result get_sr_result(void) const;
 };
 
